/*
This file was generated by the following command:

cfunctions block-china-data.c

*/
#ifndef CFH_BLOCK_CHINA_DATA_H
#define CFH_BLOCK_CHINA_DATA_H

#line 4 "block-china-data.c"
extern int n_china_ips;

#line 4649 "block-china-data.c"
extern ip_block_t china_ips[];

#endif /* CFH_BLOCK_CHINA_DATA_H */
